@@ -5,10 +5,11 @@
 # Distributed under the terms of the Modified BSD License.
 
 from .ipygany import (  # noqa
-  PolyMesh, TetraMesh, PointCloud,
-  Scene,
-  Data, Component,
-  Alpha, IsoColor, Threshold, IsoSurface, Warp
+    PolyMesh, TetraMesh, PointCloud,
+    Scene,
+    Data, Component,
+    Alpha, RGB, IsoColor, Threshold, IsoSurface, Warp,
+    Water, UnderWater
 )
 from ._version import __version__, version_info  # noqa
 
