@@ -22,16 +22,18 @@ import {
 const EXTENSION_ID = 'ipygany:plugin';
 
 /**
- * The example plugin.
+ * The ipygany plugin.
  */
-const examplePlugin: IPlugin<Application<Widget>, void> = {
+const ipyganyPlugin: IPlugin<Application<Widget>, void> = {
   id: EXTENSION_ID,
   requires: [IJupyterWidgetRegistry],
   activate: activateWidgetExtension,
   autoStart: true
-};
+} as unknown as IPlugin<Application<Widget>, void>;
+// the "as unknown as ..." typecast above is solely to support JupyterLab 1
+// and 2 in the same codebase and should be removed when we migrate to Lumino.
 
-export default examplePlugin;
+export default ipyganyPlugin;
 
 
 /**
